/* $Id: advmode_page.cpp 20 2008-09-05 18:01:46Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2008  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "advmode_page.h"
#include "aocrayon.h"

#include <QtGui>

AdvancedModePage::AdvancedModePage( QWidget *parent )
	:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	ColorsList = new QTreeWidget( this );
	ColorsList->setRootIsDecorated( false );
	ColorsList->setSortingEnabled( false );
	QStringList headers;
	headers << tr( "Color group" ) << tr( "Color" );
	ColorsList->setHeaderLabels( headers );
	ColorsList->setColumnWidth( 0, 225 );
	ColorsList->setColumnWidth( 1, 75 );
	connect( ColorsList, SIGNAL( itemDoubleClicked(QTreeWidgetItem*,int) ), SLOT( pickColor(QTreeWidgetItem*,int) ) );
	BaseLayout->addWidget( ColorsList );

	PickColorBtn = new QPushButton( this );
	PickColorBtn->setText( tr( "Change s&elected color" ) );
	PickColorBtn->setAutoDefault( false );
	connect( PickColorBtn, SIGNAL( clicked() ), SLOT( pickColor() ) );
	BaseLayout->addWidget( PickColorBtn );

	AdvHelpLabel = new QLabel( this );
	AdvHelpLabel->setText( tr(
		"<b><u>Color groups explained:</u></b><br />"
		"* The top 15 or so groups are just definitions for standard colors.<br />"
		"\tIt's best to just leave these alone...<br />"
		"* The groups starting with <font color=red>ct_</font> are internal colors. Do as above.<br />"
		"* Groups starting with <font color=red>CC</font> are used in various dialogs and<br /> other parts of the GUI"
		"\t(i.e. <font color=red>CCNPCChatColorEmote</font>)<br />"
		"* Groups starting with <font color=red>ctch_</font> are the various chat groups.<br />"
		"\t(i.e. <font color=red>ctch_clan</font> is your guild channel etc.)"
		) );
	BaseLayout->addWidget( AdvHelpLabel );
}

void AdvancedModePage::updateColors()
{
	ColorsList->clear();
	QTreeWidgetItem * item = 0;
	QFont tmpFont( "Tahoma", 10, QFont::Black );
	int n = 0;

	for( AOColors::iterator it = Colors.begin(); it != Colors.end(); it++, n++ )
	{
		item = new QTreeWidgetItem( ColorsList, item );
		item->setBackgroundColor( 0, BGColor.color() );
		item->setBackgroundColor( 1, BGColor.color() );

		item->setFont( 0, tmpFont );
		item->setFont( 1, tmpFont );

		item->setText( 0, (*it).name() );
		item->setText( 1, (*it).value() );

		QColor col( (QColor) (*it).color() );
		if( col.isValid() )
		{
			item->setTextColor( 0, col );
			item->setTextColor( 1, col );

			QPixmap *temp = new QPixmap( 15, 15 );
			temp->fill( col );
			item->setIcon( 1, *temp );
		}
	}
}

void AdvancedModePage::setBGColor( const AOColor &color )
{
	BGColor = color;
	updateColors();
}

void AdvancedModePage::pickColor( QTreeWidgetItem *item, int column )
{
	if( item == 0 && column == -1 ) return;
	QString id = item->text( 0 );
	emit pickColor( id );
}

void AdvancedModePage::pickColor()
{
	if( QTreeWidgetItem * item = ColorsList->currentItem() )
	{
		pickColor( item, 0 );
	}
}
