/* $Id: aocolor.cpp 20 2008-09-05 18:01:46Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2008  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "aocolor.h"
#include <QColor>

AOColor::AOColor(void)
{
	Name = "";
	Color = "";
	r = -1;
	g = -1;
	b = -1;
	Type = String;
}

AOColor::AOColor( const AOColor &col )
{
	Name = col.name();
	setColor( col.value() );
}

void AOColor::setColor( const QString &color )
{
	Color = color;
	if( Color.left( 2 ) == "0x" )
	{
		QString hex = Color.section( 'x', -1 );
		if( hex.length() > 6 )
		{
			Type = Hex4;
			r = hex.mid( 2, 2 ).toInt( 0, 16 );
			g = hex.mid( 4, 2 ).toInt( 0, 16 );
			b = hex.right( 2 ).toInt( 0, 16 );
		}
		else
		{
			Type = Hex3;
			r = hex.left( 2 ).toInt( 0, 16 );
			g = hex.mid( 2, 2 ).toInt( 0, 16 );
			b = hex.right( 2 ).toInt( 0, 16 );
		}
	}
	else if( Color.left( 1 ) == "#" )
	{
		QString hex = Color.section( '#', -1 );
		Type = Hex3;
		r = hex.left( 2 ).toInt( 0, 16 );
		g = hex.mid( 2, 2 ).toInt( 0, 16 );
		b = hex.right( 2 ).toInt( 0, 16 );
	}
	else
	{
		Type = String;
	}
}

void AOColor::setColor( const QColor &color )
{
	if( Type == String )
		Type = Hex3;
	r = color.red();
	g = color.green();
	b = color.blue();

	QString str;
	str.sprintf( "%02x%02x%02x", r, g, b );

	if( Type == Hex3 )
		Color = QString( "0x" + str );
	else if( Type == Hex4 )
		Color = QString( "0x00" + str );
}

QColor AOColor::color() const
{
	switch( Type )
	{
	case String:
		return QColor( Color );
	case Hex3:
	case Hex4:
		return QColor( r, g, b );
	default:
		return QColor();
	}
}

AOColor AOColors::getByName( const QString &name )
{
	for( AOColors::iterator it = begin(); it != end(); it++ )
	{
		if( (*it).name() == name )
		{
			return (*it);
		}
	}
	return AOColor();
}

bool AOColors::updateColor( const AOColor &color )
{
	for( int n = 0; n < size(); ++n )
	{
		if( at( n ).name() == color.name() )
		{
			replace( n, color );
			return true;
		}
	}
	return false;
}
