/* $Id: aocolor_widget.cpp 20 2008-09-05 18:01:46Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2008  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "aocolor_widget.h"
#include "aocolor.h"
#include "aocrayon.h"

#include <QtGui>

AOColorWidget::AOColorWidget( QWidget *parent )
	: QWidget( parent )
{
	BaseLayout = new QHBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 0 );

	ColorLabel = new QLabel( this );
	ColorLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	ColorLabel->setIndent( 5 );
	ColorLabel->setAutoFillBackground( true );
	BaseLayout->addWidget( ColorLabel );

	QFont f( "Tahoma", 10, QFont::Black );
	ColorLabel->setFont( f );

	ColorBtn = new QPushButton( this );
	ColorBtn->setFixedSize( 140, 25 );
	ColorBtn->setIconSize( QSize( 60, 15 ) );
	connect( ColorBtn, SIGNAL( clicked() ), this, SLOT( buttonClicked() ) );
	BaseLayout->addWidget( ColorBtn );
}

void AOColorWidget::setText( const QString &text )
{
	ColorLabel->setText( "<b>" + text + " :</b>" );
}

void AOColorWidget::setBGColor( const AOColor &BGColor )
{
	QPalette pal = ColorLabel->palette();
	pal.setColor( QPalette::Background, BGColor.color() );
	ColorLabel->setPalette( pal );

	pal = ColorBtn->palette();
	pal.setColor( QPalette::Button, BGColor.color() );
	ColorBtn->setPalette( pal );
}

void AOColorWidget::setToolTip( const QString &text )
{
	ColorLabel->setToolTip( text );
	ColorBtn->setToolTip( text );
}

void AOColorWidget::clear()
{
	ColorGroups.clear();
}

void AOColorWidget::addColorGroup( const QString &cg )
{
	ColorGroups.append( cg );
}

void AOColorWidget::removeColorGroup( const QString &cg )
{
	ColorGroups.removeAll( cg );
}

void AOColorWidget::updateColor()
{
	if( ColorGroups.size() > 0 )
	{
		QString cg = ColorGroups.at( 0 );
		AOColor color = Colors.getByName( cg );
		QPixmap temp( 60, 15 );
		temp.fill( color.color() );
		ColorBtn->setIcon( temp );
		QPalette pal = ColorLabel->palette();
		pal.setColor( QPalette::WindowText, color.color() );
		ColorLabel->setPalette( pal );
	}
}

void AOColorWidget::buttonClicked()
{
	emit clicked( ColorGroups );
}
