/* $Id: basicmode_page.cpp 20 2008-09-05 18:01:46Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2008  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "basicmode_page.h"
#include "aocrayon.h"
#include "aocolor_widget.h"

#include <QtGui>

BasicModePage::BasicModePage( QWidget *parent )
	:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	TabWidget = new QTabWidget( this );
	BaseLayout->addWidget( TabWidget );

	/*
	 * Basic Chat colors
	 */
	ChatTab = new QWidget;
	ChatLayout = new QVBoxLayout( ChatTab );
	ChatLayout->setSpacing( 3 );
	ChatLayout->setMargin( 5 );

	ClanBtn = new AOColorWidget( ChatTab );
	ClanBtn->setText( "Org. chat" );
	ClanBtn->addColorGroup( "ctch_clan" );
	ClanBtn->addColorGroup( "CCClanColor" );
	connect( ClanBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( ClanBtn );

	RaidBtn = new AOColorWidget( ChatTab );
	RaidBtn->setText( "Raid channel" );
	RaidBtn->addColorGroup( "ctch_raid" );
	connect( RaidBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( RaidBtn );

	PGroupBtn = new AOColorWidget( ChatTab );
	PGroupBtn->setText( "Private groups" );
	PGroupBtn->addColorGroup( "ctch_pgroup" );
	connect( PGroupBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( PGroupBtn );

	TeamBtn = new AOColorWidget( ChatTab );
	TeamBtn->setText( "Team chat" );
	TeamBtn->addColorGroup( "ctch_team" );
	TeamBtn->addColorGroup( "CCTeamColor" );
	connect( TeamBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( TeamBtn );

	TellBtn = new AOColorWidget( ChatTab );
	TellBtn->setText( "Private tells" );
	TellBtn->addColorGroup( "ct_itell" );
	TellBtn->addColorGroup( "ctch_tell" );
	TellBtn->addColorGroup( "CCTellColor" );
	connect( TellBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( TellBtn );

	OOCBtn = new AOColorWidget( ChatTab );
	OOCBtn->setText( "OOC" );
	OOCBtn->addColorGroup( "ctch_newbie" );
	OOCBtn->addColorGroup( "CCNewbieColor" );
	connect( OOCBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked( const QStringList&) ) );
	ChatLayout->addWidget( OOCBtn );

	MiscBtn = new AOColorWidget( ChatTab );
	MiscBtn->setText( "Misc *" );
	MiscBtn->setToolTip( "This is used various places, among others Org Leaders chat, and Social chat on TestLive" );
	MiscBtn->addColorGroup( "ctch_misc" );
	MiscBtn->addColorGroup( "CCMiscColor" );
	connect( MiscBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	ChatLayout->addWidget( MiscBtn );

	ChatLayout->addStretch( 1 );
	TabWidget->addTab( ChatTab, "Chat" );

	/*
	 * Basic Chat colors (cont.)
	 */
	MoreChatTab = new QWidget;
	MoreChatLayout = new QVBoxLayout( MoreChatTab );
	MoreChatLayout->setSpacing( 3 );
	MoreChatLayout->setMargin( 5 );

	VicinityBtn = new AOColorWidget( MoreChatTab );
	VicinityBtn->setText( "Vicinity" );
	VicinityBtn->addColorGroup( "ctch_vicinity" );
	VicinityBtn->addColorGroup( "CCVicinityColor" );
	connect( VicinityBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( VicinityBtn );

	WhisperBtn = new AOColorWidget( MoreChatTab );
	WhisperBtn->setText( "Whisper" );
	WhisperBtn->addColorGroup( "ctch_whisper" );
	WhisperBtn->addColorGroup( "CCWhisperColor" );
	connect( WhisperBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( WhisperBtn );

	ShoutBtn = new AOColorWidget( MoreChatTab );
	ShoutBtn->setText( "Shout" );
	ShoutBtn->addColorGroup( "ctch_shout" );
	ShoutBtn->addColorGroup( "CCShoutColor" );
	connect( ShoutBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( ShoutBtn );

	EmotesBtn = new AOColorWidget( MoreChatTab );
	EmotesBtn->setText( "Emotes" );
	EmotesBtn->addColorGroup( "ctch_emote" );
	EmotesBtn->addColorGroup( "CCEmoteColor" );
	connect( EmotesBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked( const QStringList&) ) );
	MoreChatLayout->addWidget( EmotesBtn );

	/** NOTE:
	 * Yes, shopping channels use the "seeking team" chat groups.
	 * It's actually the only channel using that group after FC
	 * removed the seeking team channels.
	 */
	ShoppingBtn = new AOColorWidget( MoreChatTab );
	ShoppingBtn->setText( "Shopping channels" );
	ShoppingBtn->addColorGroup( "ctch_seekingteam" );
	ShoppingBtn->addColorGroup( "CCSeekingTeamColor" );
	connect( ShoppingBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( ShoppingBtn );

	MyPetBtn = new AOColorWidget( MoreChatTab );
	MyPetBtn->setText( "My pet" );
	MyPetBtn->addColorGroup( "ctch_mypet" );
	connect( MyPetBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( MyPetBtn );

	OtherPetBtn = new AOColorWidget( MoreChatTab );
	OtherPetBtn->setText( "n00b's pet" );
	OtherPetBtn->addColorGroup( "ctch_otherpet" );
	connect( OtherPetBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	MoreChatLayout->addWidget( OtherPetBtn );

	MoreChatLayout->addStretch( 1 );
	TabWidget->addTab( MoreChatTab, "Chat (2)" );

	/*
	 * Info window colors
	 */
	InfoTab = new QWidget;
	InfoLayout = new QVBoxLayout( InfoTab );
	InfoLayout->setSpacing( 3 );
	InfoLayout->setMargin( 5 );

	HeadlineBtn = new AOColorWidget( InfoTab );
	HeadlineBtn->setText( "Headline" );
	HeadlineBtn->addColorGroup( "CCInfoHeadline" );
	connect( HeadlineBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked( const QStringList&) ) );
	InfoLayout->addWidget( HeadlineBtn );

	HeaderBtn = new AOColorWidget( InfoTab );
	HeaderBtn->setText( "Header" );
	HeaderBtn->addColorGroup( "CCInfoHeader" );
	connect( HeaderBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	InfoLayout->addWidget( HeaderBtn );

	TextBtn = new AOColorWidget( InfoTab );
	TextBtn->setText( "Normal Text" );
	TextBtn->addColorGroup( "CCInfoText" );
	connect( TextBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	InfoLayout->addWidget( TextBtn );

	BoldBtn = new AOColorWidget( InfoTab );
	BoldBtn->setText( "Bold Text" );
	BoldBtn->addColorGroup( "CCInfoTextBold" );
	connect( BoldBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	InfoLayout->addWidget( BoldBtn );

	InfoLayout->addStretch( 1 );
	TabWidget->addTab( InfoTab, "Info Box" );

	/*
	 * NPC Chat colors
	 */
	NPCTab = new QWidget;
	NPCLayout = new QVBoxLayout( NPCTab );
	NPCLayout->setSpacing( 3 );
	NPCLayout->setMargin( 5 );

	NPCChatBtn = new AOColorWidget( NPCTab );
	NPCChatBtn->setText( "NPC chat text" );
	NPCChatBtn->addColorGroup( "CCNPCChatText" );
	connect( NPCChatBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCChatBtn );

	NPCOOCBtn = new AOColorWidget( NPCTab );
	NPCOOCBtn->setText( "NPC OOC text" );
	NPCOOCBtn->addColorGroup( "CCNPCOOCText" );
	connect( NPCOOCBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCOOCBtn );

	NPCEmoteBtn = new AOColorWidget( NPCTab );
	NPCEmoteBtn->setText( "NPC emotes" );
	NPCEmoteBtn->addColorGroup( "CCNPCChatEmote" );
	connect( NPCEmoteBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCEmoteBtn );

	NPCSystemBtn = new AOColorWidget( NPCTab );
	NPCSystemBtn->setText( "NPC system Text" );
	NPCSystemBtn->addColorGroup( "CCNPCChatSystem" );
	connect( NPCSystemBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCSystemBtn );

	NPCQuestionBtn = new AOColorWidget( NPCTab );
	NPCQuestionBtn->setText( "Your questions" );
	NPCQuestionBtn->addColorGroup( "CCNPCChatQuestion" );
	connect( NPCQuestionBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCQuestionBtn );

	NPCDescriptBtn = new AOColorWidget( NPCTab );
	NPCDescriptBtn->setText( "Descriptions" );
	NPCDescriptBtn->addColorGroup( "CCNPCChatDescription" );
	connect( NPCDescriptBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCDescriptBtn );

	NPCTradeBtn = new AOColorWidget( NPCTab );
	NPCTradeBtn->setText( "Trading text" );
	NPCTradeBtn->addColorGroup( "CCNPCChatTrade" );
	connect( NPCTradeBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	NPCLayout->addWidget( NPCTradeBtn );

	NPCLayout->addStretch( 1 );
	TabWidget->addTab( NPCTab, "NPC Chat" );

	/*
	 * Combat colors
	 */
	CombatTab = new QWidget;
	CombatLayout = new QVBoxLayout( CombatTab );
	CombatLayout->setSpacing( 3 );
	CombatLayout->setMargin( 5 );

	MeHitByNanoBtn = new AOColorWidget( CombatTab );
	MeHitByNanoBtn->setText( "You got hit by nano" );
	MeHitByNanoBtn->addColorGroup( "CCMeHitByNanoColor" );
	connect( MeHitByNanoBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( MeHitByNanoBtn );

	OtherHitByNanoBtn = new AOColorWidget( CombatTab );
	OtherHitByNanoBtn->setText( "n00b got hit by nano" );
	OtherHitByNanoBtn->addColorGroup( "CCOtherHitByNanoColor" );
	connect( OtherHitByNanoBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( OtherHitByNanoBtn );

	MonsterHitMeBtn = new AOColorWidget( CombatTab );
	MonsterHitMeBtn->setText( "You got hit by an NPC" );
	MonsterHitMeBtn->addColorGroup( "CCMonsterHitMeColor" );
	connect( MonsterHitMeBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( MonsterHitMeBtn );

	PlayerHitMeBtn = new AOColorWidget( CombatTab );
	PlayerHitMeBtn->setText( "You got hit by a n00b" );
	PlayerHitMeBtn->addColorGroup( "CCPlayerHitMeColor" );
	connect( PlayerHitMeBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( PlayerHitMeBtn );

	MeHitOtherBtn = new AOColorWidget( CombatTab );
	MeHitOtherBtn->setText( "You hit someone" );
	MeHitOtherBtn->addColorGroup( "CCMeHitOtherColor" );
	connect( MeHitOtherBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( MeHitOtherBtn );

	OtherHitOtherBtn = new AOColorWidget( CombatTab );
	OtherHitOtherBtn->setText( "n00b got hit by other n00b" );
	OtherHitOtherBtn->addColorGroup( "CCOtherHitOtherColor" );
	connect( OtherHitOtherBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( OtherHitOtherBtn );

	OtherHitByPetBtn = new AOColorWidget( CombatTab );
	OtherHitByPetBtn->setText( "n00b got hit by your pet" );
	OtherHitByPetBtn->addColorGroup( "CCOtherHitOtherMyPetColor" );
	connect( OtherHitByPetBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	CombatLayout->addWidget( OtherHitByPetBtn );

	CombatLayout->addStretch( 1 );
	TabWidget->addTab( CombatTab, "Combat" );

	/*
	 * Misc colors
	 */
	FeedbackTab = new QWidget;
	FeedbackLayout = new QVBoxLayout( FeedbackTab );
	FeedbackLayout->setSpacing( 3 );
	FeedbackLayout->setMargin( 5 );

	TowerBtn = new AOColorWidget( FeedbackTab );
	TowerBtn->setText( "Towers &amp; Org. Msg." );
	TowerBtn->addColorGroup( "ctch_tower" );
	TowerBtn->addColorGroup( "CCTowerColor" );
	connect( TowerBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( TowerBtn );

	MeGotXPBtn = new AOColorWidget( FeedbackTab );
	MeGotXPBtn->setText( "XP/SK feedback" );
	MeGotXPBtn->addColorGroup( "CCMeGotXpColor" );
	connect( MeGotXPBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( MeGotXPBtn );

	ResearchBtn = new AOColorWidget( FeedbackTab );
	ResearchBtn->setText( "Research feedback" );
	ResearchBtn->addColorGroup( "ctch_research" );
	connect( ResearchBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( ResearchBtn );

	MeHealedBtn = new AOColorWidget( FeedbackTab );
	MeHealedBtn->setText( "You got healed..." );
	MeHealedBtn->addColorGroup( "CCMeHealedColor" );
	connect( MeHealedBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( MeHealedBtn );

	SkillBtn = new AOColorWidget( FeedbackTab );
	SkillBtn->setText( "Skill available" );
	SkillBtn->addColorGroup( "CCSkillColor" );
	connect( SkillBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( SkillBtn );

	SystemBtn = new AOColorWidget( FeedbackTab );
	SystemBtn->setText( "System messages" );
	SystemBtn->setToolTip( "Various feedback suck as \"Casting nanoprogram...\" etc." );
	SystemBtn->addColorGroup( "ct_system" );
	connect( SystemBtn, SIGNAL( clicked(const QStringList&) ), SLOT( buttonClicked(const QStringList&) ) );
	FeedbackLayout->addWidget( SystemBtn );

	FeedbackLayout->addStretch( 1 );
	TabWidget->addTab( FeedbackTab, "Misc." );

	/*
	 * Add spacer and help text
	 */
	BaseLayout->addStretch( 1 );

	BasicHelpLabel = new QLabel( this );
	BasicHelpLabel->setText( tr(
		"<strong><u>Changing your chatcolors:</u></strong><br />"
		"Change the colors you want.<br />"
		"Click <strong>Save</strong> to save the data.<br />"
		"Launch Anarchy Online.<br /><br />"
		"If you already have AO running, do this to see your changes:<br />"
		"Press <strong>CTRL + SHIFT + F7</strong>.<br />"
		"Make the <strong>Actions</strong> tab active by clicking on it.<br />"
		"Click <strong>Reload menus</strong>."
		) );
	BaseLayout->addWidget( BasicHelpLabel );
}

void BasicModePage::updateColors()
{
	/* basic chat */
	ClanBtn->updateColor();
	RaidBtn->updateColor();
	PGroupBtn->updateColor();
	TeamBtn->updateColor();
	TellBtn->updateColor();
	OOCBtn->updateColor();
	MiscBtn->updateColor();

	/* more chat */
	VicinityBtn->updateColor();
	WhisperBtn->updateColor();
	ShoutBtn->updateColor();
	EmotesBtn->updateColor();
	ShoppingBtn->updateColor();
	MyPetBtn->updateColor();
	OtherPetBtn->updateColor();

	/* Info window */
	HeadlineBtn->updateColor();
	HeaderBtn->updateColor();
	TextBtn->updateColor();
	BoldBtn->updateColor();

	/* NPC */
	NPCChatBtn->updateColor();
	NPCOOCBtn->updateColor();
	NPCEmoteBtn->updateColor();
	NPCSystemBtn->updateColor();
	NPCQuestionBtn->updateColor();
	NPCDescriptBtn->updateColor();
	NPCTradeBtn->updateColor();

	/* combat */
	MeHitByNanoBtn->updateColor();
	OtherHitByNanoBtn->updateColor();
	MonsterHitMeBtn->updateColor();
	PlayerHitMeBtn->updateColor();
	MeHitOtherBtn->updateColor();
	OtherHitOtherBtn->updateColor();
	OtherHitByPetBtn->updateColor();

	/* misc */
	TowerBtn->updateColor();
	MeGotXPBtn->updateColor();
	ResearchBtn->updateColor();
	MeHealedBtn->updateColor();
	SkillBtn->updateColor();
	SystemBtn->updateColor();
}

void BasicModePage::setBGColor( const AOColor &BGColor )
{
	/* basic chat */
	ClanBtn->setBGColor( BGColor );
	RaidBtn->setBGColor( BGColor );
	PGroupBtn->setBGColor( BGColor );
	TeamBtn->setBGColor( BGColor );
	TellBtn->setBGColor( BGColor );
	OOCBtn->setBGColor( BGColor );
	MiscBtn->setBGColor( BGColor );

	/* more chat */
	VicinityBtn->setBGColor( BGColor );
	WhisperBtn->setBGColor( BGColor );
	ShoutBtn->setBGColor( BGColor );
	EmotesBtn->setBGColor( BGColor );
	ShoppingBtn->setBGColor( BGColor );
	MyPetBtn->setBGColor( BGColor );
	OtherPetBtn->setBGColor( BGColor );

	/* Info window */
	HeadlineBtn->setBGColor( BGColor );
	HeaderBtn->setBGColor( BGColor );
	TextBtn->setBGColor( BGColor );
	BoldBtn->setBGColor( BGColor );

	/* NPC */
	NPCChatBtn->setBGColor( BGColor );
	NPCOOCBtn->setBGColor( BGColor );
	NPCEmoteBtn->setBGColor( BGColor );
	NPCSystemBtn->setBGColor( BGColor );
	NPCQuestionBtn->setBGColor( BGColor );
	NPCDescriptBtn->setBGColor( BGColor );
	NPCTradeBtn->setBGColor( BGColor );

	/* combat */
	MeHitByNanoBtn->setBGColor( BGColor );
	OtherHitByNanoBtn->setBGColor( BGColor );
	MonsterHitMeBtn->setBGColor( BGColor );
	PlayerHitMeBtn->setBGColor( BGColor );
	MeHitOtherBtn->setBGColor( BGColor );
	OtherHitOtherBtn->setBGColor( BGColor );
	OtherHitByPetBtn->setBGColor( BGColor );

	/* misc */
	TowerBtn->setBGColor( BGColor );
	MeGotXPBtn->setBGColor( BGColor );
	ResearchBtn->setBGColor( BGColor );
	MeHealedBtn->setBGColor( BGColor );
	SkillBtn->setBGColor( BGColor );
	SystemBtn->setBGColor( BGColor );
}

void BasicModePage::buttonClicked( const QStringList &cgs )
{
	emit pickColor( cgs );
}
