/* $Id: settings_page.cpp 20 2008-09-05 18:01:46Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2008  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "settings_page.h"
#include "aocrayon.h"

#include <QtGui>

SettingsPage::SettingsPage( QWidget *parent )
	:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	AOPathLayout = new QHBoxLayout;

	AOPathLabel = new QLabel( this );
	AOPathLabel->setText( "AO Install Dir:" );
	AOPathLayout->addWidget( AOPathLabel );

	AOPathBox = new QLineEdit( this );
	connect( AOPathBox, SIGNAL( textChanged(const QString&) ), SLOT( setAOPath(const QString&) ) );
	AOPathLayout->addWidget( AOPathBox );

	AOPathBtn = new QPushButton( this );
	AOPathBtn->setText( "..." );
	AOPathBtn->setFixedWidth( 30 );
	connect( AOPathBtn, SIGNAL( clicked() ), SLOT( browseAOPath() ) );
	AOPathLayout->addWidget( AOPathBtn );

	BaseLayout->addLayout( AOPathLayout );

	AOPathErrorLabel = new QLabel( this );
	AOPathErrorLabel->setText( "<font color=red><b>Selected path is not a valid AO installation!</b></font>" );
	BaseLayout->addWidget( AOPathErrorLabel );

	ReloadBtn = new QPushButton( this );
	ReloadBtn->setText( "Reload Chat color data" );
	connect( ReloadBtn, SIGNAL( clicked() ), SLOT( restoreData() ) );
	BaseLayout->addWidget( ReloadBtn );

	QFrame * Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	RestoreBackupBtn = new QPushButton( this );
	RestoreBackupBtn->setText( "Restore last backup" );
	connect( RestoreBackupBtn, SIGNAL( clicked() ), SLOT( restoreBackup() ) );
	BaseLayout->addWidget( RestoreBackupBtn );

	RestoreOriginalBtn = new QPushButton( this );
	RestoreOriginalBtn->setText( "Restore original data" );
	connect( RestoreOriginalBtn, SIGNAL( clicked() ), SLOT( restoreOriginalData() ) );
	BaseLayout->addWidget( RestoreOriginalBtn );

	RestoreBundledBtn = new QPushButton( this );
	RestoreBundledBtn->setText( "Restore original data from bundled file" );
	connect( RestoreBundledBtn, SIGNAL( clicked() ), SLOT( restoreBundledData() ) );
	BaseLayout->addWidget( RestoreBundledBtn);

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	BGColorLayout = new QHBoxLayout;

	BGColorLabel = new QLabel( this );
	BGColorLabel->setText( "Background color" );
	BGColorLabel->setIndent( 5 );
	BGColorLayout->addWidget( BGColorLabel );

	BGColorBtn = new QPushButton( this );
	BGColorBtn->setIconSize( QSize( 60, 15 ) );
	connect( BGColorBtn, SIGNAL( clicked() ), SLOT( pickBGColor() ) );
	BGColorLayout->addWidget( BGColorBtn );

	BaseLayout->addLayout( BGColorLayout );

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	ModeBtn = new QCheckBox( this );
	ModeBtn->setText( "Advanced mode" );
	connect( ModeBtn, SIGNAL( toggled(bool) ), SLOT( setMode(bool) ) );
	BaseLayout->addWidget( ModeBtn );

	BaseLayout->addStretch( 1 );
}

void SettingsPage::browseAOPath()
{
	lookupAOPath();
}

QString SettingsPage::cleanPath( const QString &path )
{
	QString clean = QDir::cleanPath( path );
	clean = QDir::convertSeparators( clean );
	return clean;
}

bool SettingsPage::lookupAOPath()
{
	QString path = QFileDialog::getExistingDirectory( this,
		tr( "Select the folder where Anarchy Online is installed:" ), AOPath );
	if( !path.isEmpty() )
	{
		setAOPath( path );
		return true;
	}
	return false;
}

void SettingsPage::setAOPath( const QString &path )
{
	AOPath = cleanPath( path );
	AOPathBox->setText( AOPath );
	if( QFile::exists( cleanPath( AOPath + GUIPATH + COLORFILE ) ) )
	{
		AOPathErrorLabel->hide();
		ReloadBtn->show();
	}
	else
	{
		AOPathErrorLabel->show();
		ReloadBtn->hide();
	}
}

QString SettingsPage::getAOPath()
{
	return AOPath;
}

bool SettingsPage::confirmAOPath()
{
	while( AOPath.isEmpty()
		|| !QFile::exists( cleanPath( AOPath + GUIPATH + COLORFILE ) ) )
	{
		if( lookupAOPath() == false )
			return false;
	}
	return true;
}

bool SettingsPage::backupOriginalData()
{
	QDir GUIDir( cleanPath( AOPath + GUIPATH ) );
	QFile XmlFile( GUIDir.filePath( COLORFILE ) );

	if( QFile::exists( XmlFile.fileName() + ".orig" ) )
	{
		int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
			"File " COLORFILE ".orig exists. Overwrite?",
			QMessageBox::Yes, QMessageBox::No );
		if( ret == QMessageBox::No )
			return false;
		else
			GUIDir.remove( COLORFILE ".orig" );
	}

	if( !XmlFile.copy( GUIDir.filePath( COLORFILE ".orig" ) ) )
		return false;

	return true;
}

void SettingsPage::restoreOriginalData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload original data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( cleanPath( AOPath + GUIPATH ) );
		QFile BackupFile( GUIDir.filePath( COLORFILE ".orig" ) );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsPage::restoreBundledData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload original data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( cleanPath( AOPath + GUIPATH ) );
		QFile BackupFile( "TextColors.orig" );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsPage::restoreBackup()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Restore last backup? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( cleanPath( AOPath + GUIPATH ) );
		QFile BackupFile( GUIDir.filePath( COLORFILE ".bak" ) );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsPage::restoreData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload saved data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		emit reloadData();
	}
}

void SettingsPage::setMode( bool mode )
{
	ModeBtn->setChecked( mode );
	emit modeChanged( mode );
}

void SettingsPage::pickBGColor()
{
	emit pickColor( "background" );
}

void SettingsPage::setBGColor( const AOColor &BGColor )
{
	QPixmap temp( 60, 15 );
	temp.fill( BGColor.color() );
	BGColorBtn->setIcon( temp );
}
